@@ -1,5 +1,5 @@
 package HTML::KhatGallery::Core;
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.2201'; # VERSION
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ HTML::KhatGallery::Core - the core methods for HTML::KhatGallery
 
 =head1 VERSION
 
-version 0.22
+version 0.2201
 
 =head1 SYNOPSIS
 
@@ -242,6 +242,7 @@ sub init {
 	$self->{top_out_dir} = $self->{top_dir};
     }
     $self->{top_out_dir} = File::Spec->rel2abs($self->{top_out_dir});
+    $self->{top_out_base} = basename($self->{top_out_dir});
 
     # trim top_url if it has a trailing slash
     if (defined $self->{top_url})
@@ -998,10 +999,14 @@ sub start_index_page {
     my @out = ();
     push @out, "<div class=\"kgindex\">\n";
 
-    # path array contains basenames from the top dir
-    # down to the current dir
+    # Path array contains basenames from the top dir down to the current dir.
     my @path = split(/[\/\\]/, $dir_state->{dir});
-    unshift @path, $self->{top_base};
+
+    # Note that what we want is the top_out_base and not the top_base
+    # because if they are not the same (because top_out_dir was set)
+    # the salient info is the output directory and not the source directory.
+    unshift @path, $self->{top_out_base};
+
     # we want to create relative links to all the dirs
     # above the current one, so work backwards
     my %uplinks = ();
@@ -1257,8 +1262,6 @@ sub make_index_style {
     margin: 10px;
 }
 .thumb {
-    /* width: ${thumb_area_width}px; */
-    /* height: ${thumb_area_height}px; */
     overflow: auto;
     font-size: small;
 }
@@ -1512,10 +1515,10 @@ sub start_image_page {
     my @out = ();
     push @out, "<div class=\"kgimage\">\n";
 
-    # path array contains basenames from the top dir
-    # down to the current dir
+    # Path array contains basenames from the top dir
+    # down to the current dir.
     my @path = split(/[\/\\]/, $dir_state->{dir});
-    unshift @path, $self->{top_base};
+    unshift @path, $self->{top_out_base};
     # we want to create relative links to all the dirs
     # including the current one, so work backwards
     my %uplinks = ();
